package pacman.logic;

import java.util.Random;

import pacman.model.Block;
import pacman.utils.Settings;
import pacman.view.GraphicsUtil;

public class Game {

	public final static int MOVE_RIGHT = 0;
	public final static int MOVE_LEFT = 1;
	public final static int MOVE_UP = 2;
	public final static int MOVE_DOWN = 3;
	
	private Block[][] blocks = new Block[Settings.cellSize][Settings.cellSize];
	
	private int x;
	private int y;
	
	public Game() {
		x = 0;
		y = 0;
		for(int i = 0; i < blocks.length; i++) {
			for(int j = 0; j < blocks[i].length; j++) {
				blocks[i][j] = new Block(Block.EMPTY);
			}
		}
		blocks[x][y].setType(Block.PACMAN);
		Random r = new Random();
		int count = 0;
		while(count < 4) {
			int randX = r.nextInt(Settings.cellSize);
			int randY = r.nextInt(Settings.cellSize);
			if(blocks[randX][randY].getType()==Block.EMPTY) {
				count++;
				blocks[randX][randY].setType(Block.POINT);
			}
		}
		
		count = 0;
		while(count < 4) {
			int randX = r.nextInt(Settings.cellSize-1)+1;
			for(int j = 0; j < blocks[randX].length/2; j++) {
				if(blocks[randX][j].getType()==Block.EMPTY) {
					blocks[randX][j].setType(Block.WALL);
				}
			}
			count++;		
		}
	}
	
	//Update the position of pacman and the images according to the direction
	public void move(int direction) {
		if(direction < MOVE_RIGHT && direction > MOVE_DOWN)
			return;
		if(!collision(newX(direction), newY(direction))) {
			blocks[x][y].setType(Block.EMPTY);
			x = newX(direction);
			y = newY(direction);
			blocks[x][y].setType(Block.PACMAN);
			GraphicsUtil.updateDirection(direction);
		}
	}
	
	public int newX(int direction) {
		if(direction == MOVE_RIGHT)
			return (x+1)%Settings.cellSize;
		else if(direction == MOVE_LEFT) {
			if(x == 0)
				return Settings.cellSize-1;
			else
				return x-1;
		}
		return x;		
	}
	
	public int newY(int direction) {
		if(direction == MOVE_UP) {
			if(y == 0)
				return Settings.cellSize-1;
			else
				return y-1;
		}
		else if(direction == MOVE_DOWN)
			return (y+1)%Settings.cellSize;
		return y;
	}
	
	public boolean collision(int newX, int newY) {
		return blocks[newX][newY].getType() == Block.WALL;
	}
	
	public Block[][] getBlocks() {
		return blocks;
	}
}
